@@ -1,9 +1,14 @@
 bayespolr <-
-function (formula, data, weights, start, ..., subset, na.action, 
-    contrasts = NULL, Hess = TRUE, model = TRUE, method = c("logistic", 
-        "probit", "cloglog", "cauchit"), drop.unused.levels=TRUE, prior.mean = 0, prior.scale = 2.5, 
-    prior.df = 1, scaled = TRUE, prior.mean.for.cutpoints = 0, 
-    prior.scale.for.cutpoints = 10, prior.df.for.cutpoints = 1, 
+function (formula, data, weights, start, ..., 
+    subset, na.action, 
+    contrasts = NULL, Hess = TRUE, model = TRUE, 
+    method = c("logistic", "probit", "cloglog", "cauchit"), 
+    drop.unused.levels=TRUE, 
+    prior.mean = 0, prior.scale = 2.5, prior.df = 1, 
+    scaled = TRUE, 
+    prior.mean.for.cutpoints = 0, 
+    prior.scale.for.cutpoints = 10, 
+    prior.df.for.cutpoints = 1, 
     n.iter = 100) 
 {
     logit <- function(p) log(p/(1 - p))
@@ -114,23 +119,39 @@ function (formula, data, weights, start, ..., subset, na.action,
         q1 <- length(lev)%/%2 
         y1 <- (y > q1)
         X <- cbind(Intercept = rep(1, n), x)
-        fit <- switch(method, logistic = bayesglm.fit(X, y1, 
-            wt, family = binomial(), offset = offset, intercept = TRUE, 
-            prior.mean = prior.mean, prior.scale = prior.scale, 
-            prior.scale.for.intercept = 10, prior.df = prior.df, 
-            scaled = scaled, control = glm.control(maxit = n.iter)), 
+        fit <- switch(method, 
+            logistic = bayesglm.fit(X, y1, wt, family = binomial(), 
+                offset = offset, intercept = TRUE, 
+                prior.mean = prior.mean, 
+                prior.scale = prior.scale, 
+                prior.scale.for.intercept = NULL, 
+                prior.df = prior.df, 
+                scaled = scaled, 
+                control = glm.control(maxit = n.iter)), 
             probit = bayesglm.fit(X, y1, wt, family = binomial("probit"), 
-                offset = offset, intercept = TRUE, prior.mean = prior.mean, 
-                prior.scale = prior.scale, prior.scale.for.intercept = 10, 
-                prior.df = prior.df, scaled = scaled, control = glm.control(maxit = n.iter)), 
+                offset = offset, intercept = TRUE, 
+                prior.mean = prior.mean, 
+                prior.scale = prior.scale, 
+                prior.scale.for.intercept = NULL, 
+                prior.df = prior.df, 
+                scaled = scaled, 
+                control = glm.control(maxit = n.iter)), 
             cloglog = bayesglm.fit(X, y1, wt, family = binomial("probit"), 
-                offset = offset, intercept = TRUE, prior.mean = prior.mean, 
-                prior.scale = prior.scale, prior.scale.for.intercept = 10, 
-                prior.df = prior.df, scaled = scaled, control = glm.control(maxit = n.iter)), 
+                offset = offset, intercept = TRUE, 
+                prior.mean = prior.mean, 
+                prior.scale = prior.scale, 
+                prior.scale.for.intercept = NULL, 
+                prior.df = prior.df, 
+                scaled = scaled, 
+                control = glm.control(maxit = n.iter)), 
             cauchit = bayesglm.fit(X, y1, wt, family = binomial("cauchit"), 
-                offset = offset, intercept = TRUE, prior.mean = prior.mean, 
-                prior.scale = prior.scale, prior.scale.for.intercept = 10, 
-                prior.df = prior.df, scaled = scaled, control = glm.control(maxit = n.iter)))
+                offset = offset, intercept = TRUE, 
+                prior.mean = prior.mean, 
+                prior.scale = prior.scale, 
+                prior.scale.for.intercept = NULL, 
+                prior.df = prior.df, 
+                scaled = scaled,
+                control = glm.control(maxit = n.iter)))
         if (!fit$converged) 
             stop("attempt for find suitable starting values failed")
         coefs <- fit$coefficients
