@@ -1,4 +1,6 @@
-display.lm <- function(object, digits=2){
+setMethod("display", signature(object = "lm"),
+    function(object, digits=2)
+    {
     call <- object$call
     summ <- summary (object)
     coef <- summ$coef[,1:2,drop=FALSE]
@@ -11,9 +13,14 @@ display.lm <- function(object, digits=2){
     cat (paste ("n = ", n, ", k = ", k,
     "\nresidual sd = ", fround (summ$sigma, digits),
     ", R-Squared = ", fround (summ$r.squared, 2), "\n", sep=""))
-}
+    }
+)
 
-display.glm <- function (object, digits = 2){
+
+
+setMethod("display", signature(object = "glm"),
+    function(object, digits=2)
+    {
     call <- object$call
     summ <- summary(object, dispersion = object$dispersion)
     coef <- matrix( NA, length( object$coefficients ),2 )
@@ -23,16 +30,6 @@ display.glm <- function (object, digits = 2){
     n <- summ$df[1] + summ$df[2]
     k <- summ$df[1]
     print(call)
-    if (!is.null(object$batch)){
-        if(max(object$batch)>0){
-            nn <- strsplit( rownames( coef )[seq( from= length( object$batch ) + 1 ,to = nrow( coef ))], "." , fixed=TRUE)
-            bb <- c( object$batch,unlist( lapply (nn , function( lst ) { lst[[3]] } ) ) ) 
-        }
-        else {bb <- c( object$batch)}
-        cc <- cbind(fround(coef, digits), bb)
-        dimnames(cc)[[2]][3]<- "batch"
-    print(cc, digits, quote=FALSE)
-    }
     pfround(coef, digits)
     cat("---\n")
     cat(paste("n = ", n, ", k = ", k, "\nresidual deviance = ", 
@@ -50,10 +47,13 @@ display.glm <- function (object, digits = 2){
                 fround(sqrt(dispersion), digits), "\n", sep = ""))
         }
     }
-}
+    }
+)
 
 
-display.mer <- function(object, digits=2){
+setMethod("display", signature(object = "mer"),
+    function(object, digits=2)
+    {
     call <- object@call
     print (call)
     #object <- summary(object)
@@ -87,10 +87,13 @@ display.mer <- function(object, digits=2){
       cat("overdispersion parameter =", fround (.Call("mer_sigma", 
         object, FALSE, PACKAGE = "lme4"), 1), "\n")
     }
-}
+    }
+)
 
 
-display.mer2 <- function(object, digits=2){
+setMethod("display", signature(object = "lmer2"),
+    function(object, digits=2)
+    {
     call <- object@call
     print (call)
     #object <- summary(object)
@@ -124,12 +127,13 @@ display.mer2 <- function(object, digits=2){
       cat("overdispersion parameter =", fround (.Call("lmer2_sigma", 
         object, FALSE, PACKAGE = "lme4"), 1), "\n")
     }
-}
+    }
+)
 
 
-
-
-display.polr <- function(object, digits=2){
+setMethod("display", signature(object = "polr"),
+    function(object, digits=2)
+    {
     call <- object$call
     summ <- summary(object)
     coef <- summ$coef[, 1:2, drop = FALSE]
@@ -145,4 +149,5 @@ display.polr <- function(object, digits=2){
         fround(summ$deviance, 1), 
         ", null deviance is not computed by polr",
         "\n", sep = ""))
-}
+    }
+)
